@@ -4,7 +4,7 @@
  * All rights reserved.  Email: russ@q12.org   Web: www.q12.org          *
  *                                                                       *
  * Threading Windows thread pool implementation file.                    *
- * Copyright (C) 2011-2019 Oleh Derevenko. All rights reserved.          *
+ * Copyright (C) 2011-2024 Oleh Derevenko. All rights reserved.          *
  * e-mail: odar@eleks.com (change all "a" to "e")                        *
  *                                                                       *
  * This library is free software; you can redistribute it and/or         *
@@ -42,7 +42,7 @@
 
 #if dBUILTIN_THREADING_IMPL_ENABLED
 
-#include <Windows.h>
+#include <windows.h>
 #include <process.h>
 #include <new>
 
